==> eric-18.11-1-any.pkg.tar.xz: usr/lib/python3.7/site-packages/eric6/WebBrowser/Bookmarks/DefaultBookmarks_rc.py <==
# -*- coding: utf-8 -*-

# Resource object code
#
# Created by: The Resource Compiler for PyQt5 (Qt v5.10.0)
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore

qt_resource_data = b"\
\x00\x00\x02\x0d\
\x00\
\x00\x09\x25\x78\x9c\xdd\x96\x5f\x6f\xda\x30\x10\xc0\xdf\xfb\x29\
\xbc\x3c\x8c\x4d\x13\xf1\x26\xed\x61\xa2\x01\x34\xfe\x4c\xea\xd4\
\xa9\xa9\xe8\x34\xf5\xd1\x71\x8e\xe0\xe2\xd8\x9e\xed\x00\xf9\xf6\
\x33\x49\x58\x81\x66\x90\xb6\x79\x5a\x5e\x1c\xfb\xce\xf7\xbb\xbb\
\x9c\xcf\x09\x86\x9b\x94\xa3\x15\x68\xc3\xa4\xe8\x7b\x9f\xfc\x8f\
\x1e\x02\x41\x65\xcc\x44\xd2\xf7\x32\x3b\xef\x7e\xf1\x86\x83\x8b\
\xe0\xcd\xe4\x66\x7c\x77\x1f\x4e\xd1\x26\x02\xee\xe6\xdb\xe1\x70\
\xdb\xe0\x02\xb9\x27\x98\x4b\x1e\x83\x46\xc5\x10\xf7\x3d\x21\x2b\
\x41\x21\xb4\xcc\x72\x18\x8c\xa4\x5c\xa6\x44\x2f\x0d\x1a\x11\x1d\
\xe0\x72\xf1\x51\x29\xaa\xc4\x68\xa1\x61\xde\xf7\x16\xd6\x2a\xd3\
\xc3\x18\x34\xa3\x5d\x16\x83\xaf\x72\xbb\x90\xa2\xab\xb4\x7c\x00\
\x6a\x8d\x2f\x75\x82\xf7\x20\x7b\xa0\xa9\xdb\x82\x7e\x41\x84\x66\
\xcc\xc2\x53\x10\xde\x91\xce\xc3\xd7\xeb\xb5\xaf\x99\x8b\x37\x22\
\x62\x49\x65\xaa\x32\xeb\x12\xe4\xbb\x37\x2c\x60\x6d\xea\xf1\x61\
\x7e\x6b\x9f\x89\x3f\x95\xbd\x3d\xcb\x7b\x76\xcd\x13\xc3\xff\x8a\
\xa3\x0a\xe3\xb7\xf5\x99\xc4\xc7\x19\xab\x37\x5e\x6f\xbb\xc6\xf1\
\x46\xcc\x18\x56\xc0\xa5\x72\x45\x73\x9a\x3e\xf9\xab\xd7\x06\x3f\
\x96\xb4\xe2\x9f\x86\x4a\x9a\xa5\x20\x2c\xb1\xae\xa2\xdb\xe0\x46\
\x5c\x26\x4d\xc0\x23\xa7\xd7\x06\x6f\x2e\x75\x96\x36\x01\x7e\xdb\
\x2a\xb6\x41\x54\x9c\x08\xb0\x67\x91\x61\xa1\x86\x6e\x6d\x7b\xd5\
\x44\xdd\x87\xd2\x50\x77\xf2\x0f\x43\x1d\x17\x7a\xaf\xe6\xee\x3a\
\x00\x67\x22\xdb\x74\x89\x52\xa6\x38\xf9\x91\x96\x6b\x03\x58\xea\
\x18\x73\xe2\x4e\xa2\x3d\xed\xcc\x57\xa5\x38\xa3\x45\x7d\x35\x2f\
\xec\x00\x97\x2d\xe1\xf9\x3d\x22\x2c\xda\xe4\x0b\xfa\xc4\x2e\xda\
\xb2\xcf\x9e\x49\x72\x45\xb9\x26\x22\xc9\x48\x02\x5b\x9c\x69\xa3\
\x71\x6c\x9d\x50\xb9\x62\xcd\xf0\x21\xa1\xcb\x2d\xfd\x4a\xc4\xb0\
\xe9\xa1\x30\x0f\xaf\x5e\x98\xe1\xa3\xd9\x51\xae\x73\x30\xa7\xae\
\xb3\x1f\x20\xb2\xff\xfc\x3e\xfb\xfc\x3a\xfe\x03\x59\x11\x43\x35\
\x53\xb6\xc7\x65\x79\x16\xfc\x42\xd2\x49\x09\xe3\x56\xf6\x86\xb3\
\x9f\xa3\xef\xd3\xf1\x5d\xbf\x83\x3e\xa0\xb8\xea\xc9\x7e\x41\x72\
\x0b\x9d\xb7\x24\x55\x97\xa3\x9b\xc9\x7d\x21\x07\x43\x89\x82\x77\
\x07\x96\xde\x5f\xd6\x3b\x3f\x03\x11\xa3\x6b\x26\x96\x67\xfd\x7e\
\x2c\x81\x00\x97\x7f\x3b\x7f\x00\x1a\xda\x9c\x8e\
"

qt_resource_name = b"\
\x00\x15\
\x0c\xd3\x2e\x3c\
\x00\x44\
\x00\x65\x00\x66\x00\x61\x00\x75\x00\x6c\x00\x74\x00\x42\x00\x6f\x00\x6f\x00\x6b\x00\x6d\x00\x61\x00\x72\x00\x6b\x00\x73\x00\x2e\
\x00\x78\x00\x62\x00\x65\x00\x6c\
"

qt_resource_struct_v1 = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\
"

qt_resource_struct_v2 = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x62\xd4\x90\x7f\x9d\
"

qt_version = QtCore.qVersion().split('.')
if qt_version < ['5', '8', '0']:
    rcc_version = 1
    qt_resource_struct = qt_resource_struct_v1
else:
    rcc_version = 2
    qt_resource_struct = qt_resource_struct_v2

def qInitResources():
    QtCore.qRegisterResourceData(rcc_version, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(rcc_version, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()

==> eric-20.01-2-any.pkg.tar.xz: usr/lib/python3.8/site-packages/eric6/WebBrowser/Bookmarks/DefaultBookmarks_rc.py <==
# -*- coding: utf-8 -*-

# Resource object code
#
# Created by: The Resource Compiler for PyQt5 (Qt v5.12.1)
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore

qt_resource_data = b"\
\x00\x00\x02\x0d\
\x00\
\x00\x09\x25\x78\x9c\xdd\x96\x5f\x6f\xda\x30\x10\xc0\xdf\xfb\x29\
\xbc\x3c\x8c\x4d\x13\xf1\x26\xed\x61\xa2\x01\x34\xfe\x4c\xea\xd4\
\xa9\xa9\xe8\x34\xf5\xd1\x71\x8e\xe0\xe2\xd8\x9e\xed\x00\xf9\xf6\
\x33\x49\x58\x81\x66\x90\xb6\x79\x5a\x5e\x1c\xfb\xce\xf7\xbb\xbb\
\x9c\xcf\x09\x86\x9b\x94\xa3\x15\x68\xc3\xa4\xe8\x7b\x9f\xfc\x8f\
\x1e\x02\x41\x65\xcc\x44\xd2\xf7\x32\x3b\xef\x7e\xf1\x86\x83\x8b\
\xe0\xcd\xe4\x66\x7c\x77\x1f\x4e\xd1\x26\x02\xee\xe6\xdb\xe1\x70\
\xdb\xe0\x02\xb9\x27\x98\x4b\x1e\x83\x46\xc5\x10\xf7\x3d\x21\x2b\
\x41\x21\xb4\xcc\x72\x18\x8c\xa4\x5c\xa6\x44\x2f\x0d\x1a\x11\x1d\
\xe0\x72\xf1\x51\x29\xaa\xc4\x68\xa1\x61\xde\xf7\x16\xd6\x2a\xd3\
\xc3\x18\x34\xa3\x5d\x16\x83\xaf\x72\xbb\x90\xa2\xab\xb4\x7c\x00\
\x6a\x8d\x2f\x75\x82\xf7\x20\x7b\xa0\xa9\xdb\x82\x7e\x41\x84\x66\
\xcc\xc2\x53\x10\xde\x91\xce\xc3\xd7\xeb\xb5\xaf\x99\x8b\x37\x22\
\x62\x49\x65\xaa\x32\xeb\x12\xe4\xbb\x37\x2c\x60\x6d\xea\xf1\x61\
\x7e\x6b\x9f\x89\x3f\x95\xbd\x3d\xcb\x7b\x76\xcd\x13\xc3\xff\x8a\
\xa3\x0a\xe3\xb7\xf5\x99\xc4\xc7\x19\xab\x37\x5e\x6f\xbb\xc6\xf1\
\x46\xcc\x18\x56\xc0\xa5\x72\x45\x73\x9a\x3e\xf9\xab\xd7\x06\x3f\
\x96\xb4\xe2\x9f\x86\x4a\x9a\xa5\x20\x2c\xb1\xae\xa2\xdb\xe0\x46\
\x5c\x26\x4d\xc0\x23\xa7\xd7\x06\x6f\x2e\x75\x96\x36\x01\x7e\xdb\
\x2a\xb6\x41\x54\x9c\x08\xb0\x67\x91\x61\xa1\x86\x6e\x6d\x7b\xd5\
\x44\xdd\x87\xd2\x50\x77\xf2\x0f\x43\x1d\x17\x7a\xaf\xe6\xee\x3a\
\x00\x67\x22\xdb\x74\x89\x52\xa6\x38\xf9\x91\x96\x6b\x03\x58\xea\
\x18\x73\xe2\x4e\xa2\x3d\xed\xcc\x57\xa5\x38\xa3\x45\x7d\x35\x2f\
\xec\x00\x97\x2d\xe1\xf9\x3d\x22\x2c\xda\xe4\x0b\xfa\xc4\x2e\xda\
\xb2\xcf\x9e\x49\x72\x45\xb9\x26\x22\xc9\x48\x02\x5b\x9c\x69\xa3\
\x71\x6c\x9d\x50\xb9\x62\xcd\xf0\x21\xa1\xcb\x2d\xfd\x4a\xc4\xb0\
\xe9\xa1\x30\x0f\xaf\x5e\x98\xe1\xa3\xd9\x51\xae\x73\x30\xa7\xae\
\xb3\x1f\x20\xb2\xff\xfc\x3e\xfb\xfc\x3a\xfe\x03\x59\x11\x43\x35\
\x53\xb6\xc7\x65\x79\x16\xfc\x42\xd2\x49\x09\xe3\x56\xf6\x86\xb3\
\x9f\xa3\xef\xd3\xf1\x5d\xbf\x83\x3e\xa0\xb8\xea\xc9\x7e\x41\x72\
\x0b\x9d\xb7\x24\x55\x97\xa3\x9b\xc9\x7d\x21\x07\x43\x89\x82\x77\
\x07\x96\xde\x5f\xd6\x3b\x3f\x03\x11\xa3\x6b\x26\x96\x67\xfd\x7e\
\x2c\x81\x00\x97\x7f\x3b\x7f\x00\x1a\xda\x9c\x8e\
"

qt_resource_name = b"\
\x00\x15\
\x0c\xd3\x2e\x3c\
\x00\x44\
\x00\x65\x00\x66\x00\x61\x00\x75\x00\x6c\x00\x74\x00\x42\x00\x6f\x00\x6f\x00\x6b\x00\x6d\x00\x61\x00\x72\x00\x6b\x00\x73\x00\x2e\
\x00\x78\x00\x62\x00\x65\x00\x6c\
"

qt_resource_struct_v1 = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\
"

qt_resource_struct_v2 = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x6a\x36\x3b\x51\x76\
"

qt_version = [int(v) for v in QtCore.qVersion().split('.')]
if qt_version < [5, 8, 0]:
    rcc_version = 1
    qt_resource_struct = qt_resource_struct_v1
else:
    rcc_version = 2
    qt_resource_struct = qt_resource_struct_v2

def qInitResources():
    QtCore.qRegisterResourceData(rcc_version, qt_resource_struct, qt_resource_name, qt_resource_data)

def qCleanupResources():
    QtCore.qUnregisterResourceData(rcc_version, qt_resource_struct, qt_resource_name, qt_resource_data)

qInitResources()
